@@ -23,18 +23,27 @@
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
-define("BAIKAL_CONTEXT", TRUE);
+
+ini_set("session.cookie_httponly", 1);
+ini_set("display_errors", 0);
+ini_set("log_errors", 1);
+
+define("BAIKAL_CONTEXT", true);
 define("PROJECT_CONTEXT_BASEURI", "/");
 
-if(file_exists(getcwd() . "/Core")) {
-	# Flat FTP mode
-	define("PROJECT_PATH_ROOT", getcwd() . "/");	#./
+if (file_exists(getcwd() . "/Core")) {
+    # Flat FTP mode
+    define("PROJECT_PATH_ROOT", getcwd() . "/");    #./
 } else {
-	# Dedicated server mode
-	define("PROJECT_PATH_ROOT", dirname(getcwd()) . "/");	#../
+    # Dedicated server mode
+    define("PROJECT_PATH_ROOT", dirname(getcwd()) . "/");    #../
 }
 
-require PROJECT_PATH_ROOT . '/vendor/autoload.php';
+if (!file_exists(PROJECT_PATH_ROOT . 'vendor/')) {
+    die('<h1>Incomplete installation</h1><p>Ba&iuml;kal dependencies have not been installed. Please, execute "<strong>composer install</strong>" in the folder where you installed Ba&iuml;kal.');
+}
+
+require PROJECT_PATH_ROOT . 'vendor/autoload.php';
 
 # Bootstraping Flake
 \Flake\Framework::bootstrap();
@@ -50,6 +59,6 @@ require PROJECT_PATH_ROOT . '/vendor/autoload.php';
 	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8"></meta>
 </head>
 <body>
-	<h2>Baïkal is running allright.</h2>
+	<h2>Baïkal is running alright.</h2>
 </body>
 </html>
