@@ -24,15 +24,16 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace BaikalAdmin\Controller\Navigation\Topbar;
 
 class Install extends \Flake\Core\Controller {
 
-	public function execute() {
-	}
+    function execute() {
+    }
 
-	public function render() {
-		$oView = new \BaikalAdmin\View\Navigation\Topbar\Install();
-		return $oView->render();
-	}
-}
\ No newline at end of file
+    function render() {
+        $oView = new \BaikalAdmin\View\Navigation\Topbar\Install();
+        return $oView->render();
+    }
+}
