@@ -24,12 +24,13 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace BaikalAdmin\Core;
 
 class View extends \Flake\Core\View {
-	public function templatesPath() {
-		$sViewName = get_class($this);
-		$sTemplate = str_replace("\\", "/", substr($sViewName, strlen("BaikalAdmin\\View\\"))) . ".html";
-		return BAIKALADMIN_PATH_TEMPLATES . $sTemplate;
-	}
-}
\ No newline at end of file
+    function templatesPath() {
+        $sViewName = get_class($this);
+        $sTemplate = str_replace("\\", "/", substr($sViewName, strlen("BaikalAdmin\\View\\"))) . ".html";
+        return BAIKALADMIN_PATH_TEMPLATES . $sTemplate;
+    }
+}
