@@ -24,19 +24,20 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace BaikalAdmin;
 
 class Framework extends \Flake\Core\Framework {
-	
-	public static function bootstrap() {
-		define("BAIKALADMIN_PATH_ROOT", PROJECT_PATH_ROOT . "Core/Frameworks/BaikalAdmin/");	# ./
-		
-		\Baikal\Framework::bootstrap();
-		\Formal\Framework::bootstrap();
 
-		$GLOBALS["ROUTER"]::setURIPath("admin/");
+    static function bootstrap() {
+        define("BAIKALADMIN_PATH_ROOT", PROJECT_PATH_ROOT . "Core/Frameworks/BaikalAdmin/");    # ./
 
-		# Include BaikalAdmin Framework config
-		require_once(BAIKALADMIN_PATH_ROOT . "config.php");
-	}
+        \Baikal\Framework::bootstrap();
+        \Formal\Framework::bootstrap();
+
+        $GLOBALS["ROUTER"]::setURIPath("admin/");
+
+        # Include BaikalAdmin Framework config
+        require_once(BAIKALADMIN_PATH_ROOT . "config.php");
+    }
 }
