@@ -24,21 +24,22 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace Flake\Controller;
 
 class HtmlBlockTemplated extends \Flake\Core\Controller {
-	
-	function __construct($sTemplatePath, $aMarkers = array()) {
-		$this->sTemplatePath = $sTemplatePath;
-		$this->aMarkers = $aMarkers;
-	}
-	
-	function render() {
-		$oTemplate = new \Flake\Core\Template($this->sTemplatePath);
-		$sHtml = $oTemplate->parse(
-			$this->aMarkers
-		);
-		
-		return $sHtml;
-	}
-}
\ No newline at end of file
+
+    function __construct($sTemplatePath, $aMarkers = []) {
+        $this->sTemplatePath = $sTemplatePath;
+        $this->aMarkers = $aMarkers;
+    }
+
+    function render() {
+        $oTemplate = new \Flake\Core\Template($this->sTemplatePath);
+        $sHtml = $oTemplate->parse(
+            $this->aMarkers
+        );
+
+        return $sHtml;
+    }
+}
