@@ -24,37 +24,39 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace Flake\Core\Database;
 
 class Sqlite extends \Flake\Core\Database {
 
-	protected $oDb = FALSE;	// current DB link
-	protected $debugOutput = FALSE;
-	protected $store_lastBuiltQuery = TRUE;
-	protected $debug_lastBuiltQuery = "";
-	protected $sDbPath = "";
+    protected $oDb = false;    // current DB link
+    protected $debugOutput = false;
+    protected $store_lastBuiltQuery = true;
+    protected $debug_lastBuiltQuery = "";
+    protected $sDbPath = "";
 
-	public function __construct($sDbPath) {
-		$this->sDbPath = $sDbPath;
-		$this->oDb = new \PDO('sqlite:' . $this->sDbPath);
-	}
-	
-	# Taken from http://dev.kohanaframework.org/issues/2985
-	public function tables() {
-		$aTables = array();
-		
-		# Find all user level table names
-		$oStmt = $this->query('SELECT name '
-		.'FROM sqlite_master '
-		.'WHERE type=\'table\' AND name NOT LIKE \'sqlite_%\' '
-		.'ORDER BY name');
-		
-		while(($aRs = $oStmt->fetch()) !== FALSE) {
-			// Get the table name from the results
-			$aTables[] = array_shift($aRs);
-		}
-		
-		reset($aTables);
-		return $aTables;
+    function __construct($sDbPath) {
+        $this->sDbPath = $sDbPath;
+        $this->oDb = new \PDO('sqlite:' . $this->sDbPath);
+        $this->oDb->setAttribute(\PDO::ATTR_ERRMODE, \PDO::ERRMODE_EXCEPTION);
     }
-}
\ No newline at end of file
+
+    # Taken from http://dev.kohanaframework.org/issues/2985
+    function tables() {
+        $aTables = [];
+
+        # Find all user level table names
+        $oStmt = $this->query('SELECT name '
+        . 'FROM sqlite_master '
+        . 'WHERE type=\'table\' AND name NOT LIKE \'sqlite_%\' '
+        . 'ORDER BY name');
+
+        while (($aRs = $oStmt->fetch()) !== false) {
+            // Get the table name from the results
+            $aTables[] = array_shift($aRs);
+        }
+
+        reset($aTables);
+        return $aTables;
+    }
+}
