@@ -24,20 +24,21 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace Flake\Core\Database;
 
 class Statement extends \Flake\Core\FLObject {
-	protected $stmt = null;
+    protected $stmt = null;
 
-	public function __construct($stmt) {
-		$this->stmt = $stmt;
-	}
+    function __construct($stmt) {
+        $this->stmt = $stmt;
+    }
 
-	public function fetch() {
-		if($this->stmt !== FALSE) {
-			return $this->stmt->fetch(\PDO::FETCH_ASSOC, \PDO::FETCH_ORI_FIRST);
-		}
+    function fetch() {
+        if ($this->stmt !== false) {
+            return $this->stmt->fetch(\PDO::FETCH_ASSOC, \PDO::FETCH_ORI_FIRST);
+        }
 
-		return FALSE;
-	}
-}
\ No newline at end of file
+        return false;
+    }
+}
