@@ -24,15 +24,16 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace Flake\Core\Datastructure;
 
 interface Chainable extends \ArrayAccess, \Iterator, \Countable {
-	
+
 #	public function &next();	# This is already specified by interface Iterator
-	public function &prev();
-	
-	public function &first();	
-	public function &last();
-	
-	public function chain(\Flake\Core\Datastructure\Chain $chain, $key);
+    function &prev();
+
+    function &first();
+    function &last();
+
+    function chain(\Flake\Core\Datastructure\Chain $chain, $key);
 }
