@@ -24,43 +24,44 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
+
 namespace Flake\Util;
 
 class Profiler extends \Flake\Core\FLObject {
-	
-	protected static $TUSAGE;
-	protected static $RUSAGE;
-	
-	protected function __construct() {
-		# Static class
-	}
-	
-	public static function start() {
-		$dat = getrusage();
-		self::$TUSAGE = microtime(TRUE);
-		self::$RUSAGE = $dat["ru_utime.tv_sec"] * 1e6 + $dat["ru_utime.tv_usec"];
-	}
 
-	public static function cpuUsage() {
-	    $dat = getrusage();
-	    $tv_usec = (($dat["ru_utime.tv_sec"] * 1e6) + $dat["ru_utime.tv_usec"]) - self::$RUSAGE;
-	    $time = (microtime(true) - self::$TUSAGE) * 1e6;
+    protected static $TUSAGE;
+    protected static $RUSAGE;
 
-	    // cpu per request
-	    if($time > 0) {
-	        $cpu = number_format(($tv_usec / $time) * 100, 2);
-	    } else {
-	        $cpu = '0.00';
-	    }
+    protected function __construct() {
+        # Static class
+    }
 
-	    return $cpu;
-	}
-	
-	public static function cpuTime() {
-	    $dat = getrusage();
-	    $tv_usec = (($dat["ru_utime.tv_sec"] * 1e6) + $dat["ru_utime.tv_usec"]) - self::$RUSAGE;
-	    $time = (microtime(true) - self::$TUSAGE) * 1e6;
-		$cpuusage = ($tv_usec / $time);
-	    return round(($time  / 1000) * $cpuusage);
-	}
-}
\ No newline at end of file
+    static function start() {
+        $dat = getrusage();
+        self::$TUSAGE = microtime(true);
+        self::$RUSAGE = $dat["ru_utime.tv_sec"] * 1e6 + $dat["ru_utime.tv_usec"];
+    }
+
+    static function cpuUsage() {
+        $dat = getrusage();
+        $tv_usec = (($dat["ru_utime.tv_sec"] * 1e6) + $dat["ru_utime.tv_usec"]) - self::$RUSAGE;
+        $time = (microtime(true) - self::$TUSAGE) * 1e6;
+
+        // cpu per request
+        if ($time > 0) {
+            $cpu = number_format(($tv_usec / $time) * 100, 2);
+        } else {
+            $cpu = '0.00';
+        }
+
+        return $cpu;
+    }
+
+    static function cpuTime() {
+        $dat = getrusage();
+        $tv_usec = (($dat["ru_utime.tv_sec"] * 1e6) + $dat["ru_utime.tv_usec"]) - self::$RUSAGE;
+        $time = (microtime(true) - self::$TUSAGE) * 1e6;
+        $cpuusage = ($tv_usec / $time);
+        return round(($time  / 1000) * $cpuusage);
+    }
+}
